@@ -33,7 +33,7 @@ use mit_commit_message_lints::{
 use serde::Serialize;
 use tinytemplate::TinyTemplate;
 
-use crate::{cli::app, errors::MitPrepareCommitMessageError::MissingCommitFilePath};
+use crate::{cli::cli, errors::MitPrepareCommitMessageError::MissingCommitFilePath};
 
 mod cli;
 mod errors;
@@ -45,7 +45,7 @@ struct Context<'a> {
 
 fn main() -> Result<()> {
     miette_install();
-    let mut app = app();
+    let mut app = cli();
     let matches = app.clone().get_matches();
 
     // Simply print and exit if completion option is given.
